@@ -24,3 +24,5 @@ def get_leaflet_asset():
     yield 'quill.snow.css'
     yield 'custom.css'
     yield 'quill.js'
+    yield 'quill.placeholder.css'
+    yield 'quill.placeholder.js'
